﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Joseph Helm and Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.PackingEncoding.GroupingVector {
  [Item("ChangeGroupingMoveAttribute", "Specifies the tabu attributes for a ChangeGrouping move on a grouping vector.")]
  [StorableClass]
  public class ChangeGroupingMoveAttribute : GroupingMoveAttribute {
    [Storable]
    public int ItemIndex { get; protected set; }
    [Storable]
    public int AssignedBin { get; protected set; }

    [StorableConstructor]
    protected ChangeGroupingMoveAttribute(bool deserializing) : base(deserializing) { }
    protected ChangeGroupingMoveAttribute(ChangeGroupingMoveAttribute original, Cloner cloner)
      : base(original, cloner) {
      this.ItemIndex = original.ItemIndex;
      this.AssignedBin = original.AssignedBin;
    }
    public ChangeGroupingMoveAttribute() : this(-1, -1, -1) { }
    public ChangeGroupingMoveAttribute(int itemIndex, int assignedBin, double moveQuality)
      : base(moveQuality) {
      ItemIndex = itemIndex;
      AssignedBin = assignedBin;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new ChangeGroupingMoveAttribute(this, cloner);
    }
  }
}
